==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/PARTSABCANALYSIS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour PARTSABCANALYSIS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PARTSABCANALYSIS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BCUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CCUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TODATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ABCANALYSISTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTSABCANALYSIS_Type", propOrder = {
    "organizationid",
    "storeid",
    "acutoffpoint",
    "bcutoffpoint",
    "ccutoffpoint",
    "fromdate",
    "todate",
    "abcanalysistype"
})
public class PARTSABCANALYSIS_Type {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STOREID")
    protected STOREID_Type storeid;
    @XmlElement(name = "ACUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer acutoffpoint;
    @XmlElement(name = "BCUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer bcutoffpoint;
    @XmlElement(name = "CCUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer ccutoffpoint;
    @XmlElement(name = "FROMDATE")
    protected DATETIME fromdate;
    @XmlElement(name = "TODATE")
    protected DATETIME todate;
    @XmlElement(name = "ABCANALYSISTYPE", required = true)
    protected ABCANALYSISTYPE_Type abcanalysistype;

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété acutoffpoint.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getACUTOFFPOINT() {
        return acutoffpoint;
    }

    /**
     * Définit la valeur de la propriété acutoffpoint.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setACUTOFFPOINT(Integer value) {
        this.acutoffpoint = value;
    }

    /**
     * Obtient la valeur de la propriété bcutoffpoint.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getBCUTOFFPOINT() {
        return bcutoffpoint;
    }

    /**
     * Définit la valeur de la propriété bcutoffpoint.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setBCUTOFFPOINT(Integer value) {
        this.bcutoffpoint = value;
    }

    /**
     * Obtient la valeur de la propriété ccutoffpoint.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCCUTOFFPOINT() {
        return ccutoffpoint;
    }

    /**
     * Définit la valeur de la propriété ccutoffpoint.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setCCUTOFFPOINT(Integer value) {
        this.ccutoffpoint = value;
    }

    /**
     * Obtient la valeur de la propriété fromdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getFROMDATE() {
        return fromdate;
    }

    /**
     * Définit la valeur de la propriété fromdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setFROMDATE(DATETIME value) {
        this.fromdate = value;
    }

    /**
     * Obtient la valeur de la propriété todate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTODATE() {
        return todate;
    }

    /**
     * Définit la valeur de la propriété todate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTODATE(DATETIME value) {
        this.todate = value;
    }

    /**
     * Obtient la valeur de la propriété abcanalysistype.
     * 
     * @return
     *     possible object is
     *     {@link ABCANALYSISTYPE_Type }
     *     
     */
    public ABCANALYSISTYPE_Type getABCANALYSISTYPE() {
        return abcanalysistype;
    }

    /**
     * Définit la valeur de la propriété abcanalysistype.
     * 
     * @param value
     *     allowed object is
     *     {@link ABCANALYSISTYPE_Type }
     *     
     */
    public void setABCANALYSISTYPE(ABCANALYSISTYPE_Type value) {
        this.abcanalysistype = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/PARTSABCANALYSIS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for PARTSABCANALYSIS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTSABCANALYSIS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BCUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CCUTOFFPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TODATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ABCANALYSISTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTSABCANALYSIS_Type", propOrder = {
    "organizationid",
    "storeid",
    "acutoffpoint",
    "bcutoffpoint",
    "ccutoffpoint",
    "fromdate",
    "todate",
    "abcanalysistype"
})
public class PARTSABCANALYSIS_Type {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STOREID")
    protected STOREID_Type storeid;
    @XmlElement(name = "ACUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer acutoffpoint;
    @XmlElement(name = "BCUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer bcutoffpoint;
    @XmlElement(name = "CCUTOFFPOINT")
    @XmlSchemaType(name = "integer")
    protected Integer ccutoffpoint;
    @XmlElement(name = "FROMDATE")
    protected DATETIME fromdate;
    @XmlElement(name = "TODATE")
    protected DATETIME todate;
    @XmlElement(name = "ABCANALYSISTYPE", required = true)
    protected ABCANALYSISTYPE_Type abcanalysistype;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the acutoffpoint property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getACUTOFFPOINT() {
        return acutoffpoint;
    }

    /**
     * Sets the value of the acutoffpoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setACUTOFFPOINT(Integer value) {
        this.acutoffpoint = value;
    }

    /**
     * Gets the value of the bcutoffpoint property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getBCUTOFFPOINT() {
        return bcutoffpoint;
    }

    /**
     * Sets the value of the bcutoffpoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setBCUTOFFPOINT(Integer value) {
        this.bcutoffpoint = value;
    }

    /**
     * Gets the value of the ccutoffpoint property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getCCUTOFFPOINT() {
        return ccutoffpoint;
    }

    /**
     * Sets the value of the ccutoffpoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setCCUTOFFPOINT(Integer value) {
        this.ccutoffpoint = value;
    }

    /**
     * Gets the value of the fromdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getFROMDATE() {
        return fromdate;
    }

    /**
     * Sets the value of the fromdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setFROMDATE(DATETIME value) {
        this.fromdate = value;
    }

    /**
     * Gets the value of the todate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTODATE() {
        return todate;
    }

    /**
     * Sets the value of the todate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTODATE(DATETIME value) {
        this.todate = value;
    }

    /**
     * Gets the value of the abcanalysistype property.
     * 
     * @return
     *     possible object is
     *     {@link ABCANALYSISTYPE_Type }
     *     
     */
    public ABCANALYSISTYPE_Type getABCANALYSISTYPE() {
        return abcanalysistype;
    }

    /**
     * Sets the value of the abcanalysistype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ABCANALYSISTYPE_Type }
     *     
     */
    public void setABCANALYSISTYPE(ABCANALYSISTYPE_Type value) {
        this.abcanalysistype = value;
    }

}
